"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ZohoBooks = void 0;
const operations_1 = require("./operations");
const fields_1 = require("./fields");
class ZohoBooks {
    constructor() {
        this.description = {
            displayName: 'Zoho Books',
            name: 'ZohoBooks',
            icon: 'file:zohobooks.svg',
            group: ['transform'],
            version: 1,
            subtitle: '={{$parameter["operation"] + ": " + $parameter["resource"]}}',
            description: 'Implement Zoho Books API into n8n for automation',
            defaults: {
                name: 'ZohoBooks',
            },
            inputs: ['main'],
            outputs: ['main'],
            credentials: [
                {
                    name: 'zohoBooksOAuth2Api',
                    required: true,
                },
            ],
            requestDefaults: {
                baseURL: 'https://books.zoho.in/api/v3',
                headers: {
                    Accept: 'application/json',
                    'Content-Type': 'application/json',
                },
            },
            properties: [
                {
                    displayName: 'Resource',
                    name: 'resource',
                    type: 'options',
                    noDataExpression: true,
                    options: [
                        {
                            name: 'Bills',
                            value: 'bills',
                        },
                        {
                            name: 'Contact Persons',
                            value: 'contactPersons',
                        },
                        {
                            name: 'Contacts',
                            value: 'contacts',
                        },
                        {
                            name: 'Customer Payments',
                            value: 'customerPayments',
                        },
                        {
                            name: 'Estimates',
                            value: 'estimates',
                        },
                        {
                            name: 'Expenses',
                            value: 'expenses',
                        },
                        {
                            name: 'Invoices',
                            value: 'invoices',
                        },
                        {
                            name: 'Items',
                            value: 'items',
                        },
                        {
                            name: 'Sales Orders',
                            value: 'salesOrders',
                        },
                    ],
                    default: 'contacts',
                },
                ...operations_1.billsOperations,
                ...operations_1.contactsOperations,
                ...fields_1.billsFields,
                ...fields_1.contactsFields,
            ],
        };
    }
}
exports.ZohoBooks = ZohoBooks;
//# sourceMappingURL=ZohoBooks.node.js.map